/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    5635-34 Springhouse Dr.
    Pleasanton, CA 94588 (USA)
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_gbaaudio.c,v 1.2 2001/04/26 16:50:17 hercules Exp $";
#endif

/* Allow access to a raw mixing buffer (For IRIX 6.5 and higher) */

#include <stdlib.h>

#include "SDL.h"
#include "SDL_endian.h"
#include "SDL_timer.h"
#include "SDL_audio.h"
#include "SDL_audiomem.h"
#include "SDL_audio_c.h"
#include "SDL_gbaaudio.h"


/* Audio driver functions */
static int GBA_OpenAudio(_THIS, SDL_AudioSpec *spec);
static void GBA_WaitAudio(_THIS);
static void GBA_PlayAudio(_THIS);
static Uint8 *GBA_GetAudioBuf(_THIS);
static void GBA_CloseAudio(_THIS);

/* Audio driver bootstrap functions */

static int Audio_Available(void)
{
	return 0;
}

static void Audio_DeleteDevice(SDL_AudioDevice *device)
{
}

static SDL_AudioDevice *Audio_CreateDevice(int devindex)
{
	SDL_AudioDevice *this;

	/* Initialize all variables that we clean on shutdown */
	this = (SDL_AudioDevice *)malloc(sizeof(SDL_AudioDevice));
	if ( this ) {
		memset(this, 0, (sizeof *this));
		this->hidden = (struct SDL_PrivateAudioData *)
				malloc((sizeof *this->hidden));
	}
	if ( (this == NULL) || (this->hidden == NULL) ) {
		SDL_OutOfMemory();
		if ( this ) {
			free(this);
		}
		return(0);
	}
	memset(this->hidden, 0, (sizeof *this->hidden));

	/* Set the function pointers */
	this->OpenAudio = GBA_OpenAudio;
	this->WaitAudio = GBA_WaitAudio;
	this->PlayAudio = GBA_PlayAudio;
	this->GetAudioBuf = GBA_GetAudioBuf;
	this->CloseAudio = GBA_CloseAudio;

	this->free = Audio_DeleteDevice;

	return this;
}

AudioBootStrap GBA_AUDIO_bootstrap = {
	"gba", "GBA audio",
	Audio_Available, Audio_CreateDevice
};


void static GBA_WaitAudio(_THIS)
{
}

static void GBA_PlayAudio(_THIS)
{
}

static Uint8 *GBA_GetAudioBuf(_THIS)
{
	return(mixbuf);
}

static void GBA_CloseAudio(_THIS)
{
	if ( mixbuf != NULL ) {
		SDL_FreeAudioMem(mixbuf);
		mixbuf = NULL;
	}
}

static int GBA_OpenAudio(_THIS, SDL_AudioSpec *spec)
{
	/* We're ready to rock and roll. :-) */
	return(0);
}
