/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998, 1999, 2000, 2001  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@devolution.com
*/

#ifdef SAVE_RCSID
static char rcsid =
 "@(#) $Id: SDL_systimer.c,v 1.2 2001/04/26 16:50:18 hercules Exp $";
#endif

#include "SDL_thread.h"
#include "SDL_timer.h"
#include "SDL_error.h"
#include "SDL_timer_c.h"

#define GBA_TIMERBASE 0x4000100
#define GBA_TIMER0 (*(volatile Uint16*)GBA_TIMERBASE)
#define GBA_TIMER0REG (*(volatile Uint16*)(0x4000102))
#define GBA_TIMER1 (*(volatile Uint16*)(GBA_TIMERBASE+4))
#define GBA_TIMER1REG (*(volatile Uint16*)(GBA_TIMERBASE+6))
#define GBA_TIMER2 (*(volatile Uint16*)(GBA_TIMERBASE+8))
#define GBA_TIMER2REG (*(volatile Uint16*)(GBA_TIMERBASE+10))
#define GBA_TIMER3 (*(volatile Uint16*)(GBA_TIMERBASE+12))
#define GBA_TIMER3REG (*(volatile Uint16*)(GBA_TIMERBASE+14))

#define timers2ms(tlow,thigh) ((tlow>>4)+(thigh<<12))	/* assuming 16384 Hz timer */

void SDL_StartTicks(void)
{
	GBA_TIMER0=0;
	GBA_TIMER1=0;
	GBA_TIMER1REG=(1<<7)|(1<<2); /* enable, cascade */
	GBA_TIMER0REG=(1<<7)|3; /* enable, 1/1024 CLK ~ 16376 Hz */
}

Uint32 SDL_GetTicks(void)
{
	return timers2ms(GBA_TIMER0, GBA_TIMER1);
}

void SDL_Delay(Uint32 ms)
{
	int now;
	now=timers2ms(GBA_TIMER0, GBA_TIMER1);
	while(timers2ms(GBA_TIMER0,GBA_TIMER1)<now+ms);
}

/* This is only called if the event thread is not running */
int SDL_SYS_TimerInit(void)
{
}

void SDL_SYS_TimerQuit(void)
{
}

int SDL_SYS_StartTimer(void)
{
}

void SDL_SYS_StopTimer(void)
{
}
